@@ -136,7 +136,7 @@ package Astro::Coord::ECI::Utils;
 use strict;
 use warnings;
 
-our $VERSION = '0.106_01';
+our $VERSION = '0.107_01';
 our @ISA = qw{Exporter};
 
 use Carp;
@@ -942,8 +942,8 @@ to load the same module simply give the cached results.
 	# I considered Module::Load here, but it appears not to support
 	# .pmc files. No, it's not an issue at the moment, but it may be
 	# if Perl 6 becomes a reality.
-	$rslt{$module} = eval "require $module";
-	$@ and croak ($error{$module} = $@);
+	$rslt{$module} = eval "require $module"
+	    or croak( $error{$module} = $@ );
 	return $rslt{$module};
     }
 }	# End local symbol block.
